/**
 * @file        ADSO-52650
 * @description Verify blending plan details bar chart
 * @author      Wong Jia Hui (jiahui.wong@3ds.com)
 * @copyright   Dassault Systèmes
 */

import { qCustomMatcher } from '../../e2elib/lib/src/main/qmatchers.const';
import { AppMP, Demo, Scenario } from '../../libmp/appmp';
import { dataMetalsProducts, dataMetalsProductsProvider } from '../../libmp/data/data.product';
import { StepNavigationPanel } from '../../libmp/forms/navigationpanel/form.navigationpanel';
import { StepMatrix } from '../../libappsop/matrixeditorsop';
import { MatrixEditorBlendingPlan } from '../../libmp/forms/form.blendingplan';
import { CellLocator } from '../../libappbase/matrixeditorbase';
import { startOfPlanningYear } from '../../libmp/data/data.period';
import { DataMetalsPISP } from '../../libmp/data/data.pisp';
import { StepList } from '../../libappsop/listsop';
import { FormBlendingPlanDetails, FormBlendingPlanDetailsFields, ListNewSupply } from '../../libmp/forms/form.blendingplandetails';
import { StepDialog } from '../../libappsop/dialogsop';
import { StepChart } from '../../libappsop/chartsop';

describe('ADSO-52650 - Verify blending plan details bar chart', () => {
  const appMP = AppMP.getInstance();
  const formBlendingPlanDetails = appMP.viewBlendingPlan.formBlendingPlanDetails;
  const formBlendingPlanDetailsBarChart = appMP.viewBlendingPlan.formBlendingPlanDetailsBarChart;
  const meBlendingPlan = appMP.viewBlendingPlan.formBlendingPlan.meBlendingPlan;
  const listBlendingPlanDetailsNewSupply = appMP.viewBlendingPlan.formBlendingPlanDetails.listNewSupply;
  const formNavigation = appMP.formNavigation;

  const verifyToggleFilterDefaultTrue: FormBlendingPlanDetailsFields = { ToggleFilterByBlendingPlan: true };

  const cellLocation1: CellLocator = {
    columnName: `1-Jan-${startOfPlanningYear}`,
    rowName: DataMetalsPISP.MoltenAluminum5XXXInCasterLaQuinta,
  };

  const cellLocation2: CellLocator = {
    columnName: `1-Feb-${startOfPlanningYear}`,
    rowName: DataMetalsPISP.MoltenAluminum5XXXInCasterLaQuinta,
  };

  beforeAll(async () => {
    jasmine.addMatchers(qCustomMatcher);
    await appMP.login();
  });

  afterAll(async () => {
    await appMP.cleanupAndLogout();
  });

  afterEach(async () => {
    await appMP.checkToastMessage();
  });

  it(`Step 1 - ${AppMP.getDemoDataPath(Demo.Metals, Scenario.Base)}`, async () => {
    await appMP.createDemoDataset(Demo.Metals, Scenario.Base);
  });

  it(`Step 2 - Open view ${appMP.viewBlendingPlan.viewPath}`, async () => {
    await appMP.viewBlendingPlan.switchTo();
  });

  it(`Step 3 - ${StepNavigationPanel.showProductsList()} ${StepNavigationPanel.checkProducts([dataMetalsProducts.MoltenAluminum5XXX.Name])}`, async () => {
    await formNavigation.toggleProductList(true);
    const row = await formNavigation.listProduct.getRow([dataMetalsProductsProvider, dataMetalsProducts.MoltenAluminum5XXX]);
    await formNavigation.listProduct.toggleRowCheckbox(row, true);
  });

  it(`Step 4 - ${StepDialog.verifyDialogValues(FormBlendingPlanDetails.title, verifyToggleFilterDefaultTrue)}`, async () => {
    await formBlendingPlanDetails.cbFilterByBlendingPlan.verifyValue('true');
  });

  it(`Step 5 - ${StepMatrix.selectCells(MatrixEditorBlendingPlan.title, [cellLocation1, cellLocation2])}`, async () => {
    await meBlendingPlan.selectCells([cellLocation1, cellLocation2]);
  });

  it(`Step 6 - ${StepList.verifyTotalRow(ListNewSupply.title, 2)}`, async () => {
    await listBlendingPlanDetailsNewSupply.verifyTotalRow(2);
  });

  it(`Step 7 - ${StepList.selectAllRows(ListNewSupply.title)} ${StepChart.verifyXAxisLabelCount(2)}`, async () => {
    await listBlendingPlanDetailsNewSupply.selectListRowsByIndex([1], false, true);
    await formBlendingPlanDetailsBarChart.chartBlendingPlanDetails.verifyXAxisLabelCount(2);
  });

  it(`Step 8 - ${StepChart.verifyXAxisLabelTitle([cellLocation1.columnName, cellLocation2.columnName])}`, async () => {
    await formBlendingPlanDetailsBarChart.chartBlendingPlanDetails.verifyXAxisLabelTitle([cellLocation1.columnName, cellLocation2.columnName]);
  });

  it(`Step 9 - ${StepChart.verifyNrOfSeries(12)}`, async () => {
    await formBlendingPlanDetailsBarChart.chartBlendingPlanDetails.verifyNrOfSeries(12);
  });

 });
